==> jc-1.4.0.tar.gz: javax/swing/colorchooser/DefaultSwatchChooserPanel__24RecentPanelLayout.h <==
// class javax.swing.colorchooser.DefaultSwatchChooserPanel$RecentPanelLayout

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fb17ecf4e6efe521 javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout_H_
#define _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Container$object;
struct _jc_java_awt_Dimension$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$sub_refs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$refs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$nonrefs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object;

typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$vmethods	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$vtable	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$vtype	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$vtype;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object *);

// Virtual methods
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$method$addLayoutComponent$784c308b12270c9d(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object *, struct _jc_java_lang_String$object *, struct _jc_java_awt_Component$object *);
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$method$layoutContainer$8a99e8b5ce38e753(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object *, struct _jc_java_awt_Container$object *);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$method$minimumLayoutSize$42562182f8f0cd6a(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object *, struct _jc_java_awt_Container$object *);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$method$preferredLayoutSize$4c5cb50e6266027d(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object *, struct _jc_java_awt_Container$object *);
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$method$removeLayoutComponent$94e2b376e31bbde2(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object *, struct _jc_java_awt_Component$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$method_info$addLayoutComponent$784c308b12270c9d;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$method_info$layoutContainer$8a99e8b5ce38e753;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$method_info$minimumLayoutSize$42562182f8f0cd6a;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$method_info$preferredLayoutSize$4c5cb50e6266027d;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$method_info$removeLayoutComponent$94e2b376e31bbde2;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$vmethods {
	void	(*addLayoutComponent$784c308b12270c9d)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object *, struct _jc_java_lang_String$object *, struct _jc_java_awt_Component$object *);
	void	(*layoutContainer$8a99e8b5ce38e753)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object *, struct _jc_java_awt_Container$object *);
	struct _jc_java_awt_Dimension$object	*(*minimumLayoutSize$42562182f8f0cd6a)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object *, struct _jc_java_awt_Container$object *);
	struct _jc_java_awt_Dimension$object	*(*preferredLayoutSize$4c5cb50e6266027d)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object *, struct _jc_java_awt_Container$object *);
	void	(*removeLayoutComponent$94e2b376e31bbde2)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object *, struct _jc_java_awt_Component$object *);
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$vmethods	javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$refs {
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$sub_refs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$sub_nonrefs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object {
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$vtype _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout_H_ */

==> jc-1.4.6.tar.gz: javax/swing/colorchooser/DefaultSwatchChooserPanel__24RecentPanelLayout.h <==
// class javax.swing.colorchooser.DefaultSwatchChooserPanel$RecentPanelLayout

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f6945bfcc19880e0 javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout_H_
#define _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Container$object;
struct _jc_java_awt_Dimension$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$sub_refs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$refs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$nonrefs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object;

typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$vmethods	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$vtable	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$vtype	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$vtype;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$method$addLayoutComponent$784c308b12270c9d(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object *, struct _jc_java_lang_String$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$method$layoutContainer$8a99e8b5ce38e753(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$method$minimumLayoutSize$42562182f8f0cd6a(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$method$preferredLayoutSize$4c5cb50e6266027d(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$method$removeLayoutComponent$94e2b376e31bbde2(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$method_info$addLayoutComponent$784c308b12270c9d;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$method_info$layoutContainer$8a99e8b5ce38e753;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$method_info$minimumLayoutSize$42562182f8f0cd6a;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$method_info$preferredLayoutSize$4c5cb50e6266027d;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$method_info$removeLayoutComponent$94e2b376e31bbde2;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$vmethods {
	void	(*addLayoutComponent$784c308b12270c9d)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object *, struct _jc_java_lang_String$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
	void	(*layoutContainer$8a99e8b5ce38e753)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*minimumLayoutSize$42562182f8f0cd6a)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*preferredLayoutSize$4c5cb50e6266027d)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
	void	(*removeLayoutComponent$94e2b376e31bbde2)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$vmethods	javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$refs {
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$sub_refs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$sub_nonrefs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$object {
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$vtype _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentPanelLayout_H_ */
